==> haskell-hscolour-1.25-3-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hscolour
version:              1.25
visibility:           public
id:                   hscolour-1.25-61St7PjQxrJB3Zc5RdCary
key:                  hscolour-1.25-61St7PjQxrJB3Zc5RdCary
license:              LicenseRef-LGPL
copyright:            2003-2023 Malcolm Wallace; 2006 Bjorn Bringert
maintainer:           Malcolm Wallace
author:               Malcolm Wallace
homepage:             http://code.haskell.org/~malcolm/hscolour/
synopsis:             Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.

category:             Language
abi:                  6888fa4a10d49b376faca72df037b266
exposed:              True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hscolour-1.25
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hscolour-1.25
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hscolour-1.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hscolour
hs-libraries:         HShscolour-1.25-61St7PjQxrJB3Zc5RdCary
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html:         /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hscolour-1.25-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hscolour.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hscolour
version:              1.25
visibility:           public
id:                   hscolour-1.25-HwzoExZOoESFzEOPP6jL7H
key:                  hscolour-1.25-HwzoExZOoESFzEOPP6jL7H
license:              LicenseRef-LGPL
copyright:            2003-2023 Malcolm Wallace; 2006 Bjorn Bringert
maintainer:           Malcolm Wallace
author:               Malcolm Wallace
homepage:             http://code.haskell.org/~malcolm/hscolour/
synopsis:             Colourise Haskell code.
description:
    hscolour is a small Haskell script to colourise Haskell code. It currently
    has six output formats:
    ANSI terminal codes (optionally XTerm-256colour codes),
    HTML 3.2 with <font> tags,
    HTML 4.01 with CSS,
    HTML 4.01 with CSS and mouseover annotations,
    XHTML 1.0 with inline CSS styling,
    LaTeX,
    and mIRC chat codes.

category:             Language
abi:                  18cd54e526d6640902959771d89c3ae8
exposed:              True
exposed-modules:
    Language.Haskell.HsColour Language.Haskell.HsColour.ACSS
    Language.Haskell.HsColour.ANSI Language.Haskell.HsColour.Anchors
    Language.Haskell.HsColour.CSS Language.Haskell.HsColour.Classify
    Language.Haskell.HsColour.ColourHighlight
    Language.Haskell.HsColour.Colourise
    Language.Haskell.HsColour.General Language.Haskell.HsColour.HTML
    Language.Haskell.HsColour.InlineCSS Language.Haskell.HsColour.LaTeX
    Language.Haskell.HsColour.MIRC Language.Haskell.HsColour.Options
    Language.Haskell.HsColour.Output Language.Haskell.HsColour.TTY

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/hscolour-1.25
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/hscolour-1.25
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/hscolour-1.25
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hscolour
hs-libraries:         HShscolour-1.25-HwzoExZOoESFzEOPP6jL7H
depends:              base-4.18.3.0 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-hscolour/html/hscolour.haddock
haddock-html:         /usr/share/doc/haskell-hscolour/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
